@@ -7,7 +7,7 @@
 #  define VTKFILTERSMODELING_NO_EXPORT
 #else
 #  ifndef VTKFILTERSMODELING_EXPORT
-#    ifdef vtkFiltersModeling_EXPORTS
+#    ifdef FiltersModeling_EXPORTS
         /* We are building this library */
 #      define VTKFILTERSMODELING_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,20 @@
 
 #ifndef VTKFILTERSMODELING_DEPRECATED
 #  define VTKFILTERSMODELING_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKFILTERSMODELING_DEPRECATED_EXPORT VTKFILTERSMODELING_EXPORT __attribute__ ((__deprecated__))
-#  define VTKFILTERSMODELING_DEPRECATED_NO_EXPORT VTKFILTERSMODELING_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKFILTERSMODELING_NO_DEPRECATED
+#ifndef VTKFILTERSMODELING_DEPRECATED_EXPORT
+#  define VTKFILTERSMODELING_DEPRECATED_EXPORT VTKFILTERSMODELING_EXPORT VTKFILTERSMODELING_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersGeneralModule.h"
-#include "vtkFiltersSourcesModule.h"
-
+#ifndef VTKFILTERSMODELING_DEPRECATED_NO_EXPORT
+#  define VTKFILTERSMODELING_DEPRECATED_NO_EXPORT VTKFILTERSMODELING_NO_EXPORT VTKFILTERSMODELING_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKFILTERSMODELING_NO_DEPRECATED
+#    define VTKFILTERSMODELING_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKFILTERSMODELING_EXPORT_H */
