@@ -22,42 +22,44 @@
  * @sa
  * vtkDataSetGhostGenerator, vtkPUniformGridGhostDataGenerator,
  * vtkPStructuredGridGhostDataGenerator, vtkPRectilinearGridGhostDataGenerator
-*/
+ */
 
 #ifndef vtkPDataSetGhostGenerator_h
 #define vtkPDataSetGhostGenerator_h
 
-#include "vtkFiltersParallelGeometryModule.h" // For export macro
 #include "vtkDataSetGhostGenerator.h"
+#include "vtkDeprecation.h"                   // For VTK_DEPRECATED_IN_9_1_0
+#include "vtkFiltersParallelGeometryModule.h" // For export macro
 
 class vtkMultiProcessController;
 class vtkMultiBlockDataSet;
 
-class VTKFILTERSPARALLELGEOMETRY_EXPORT vtkPDataSetGhostGenerator :
-  public vtkDataSetGhostGenerator
+class VTK_DEPRECATED_IN_9_1_0(
+  "Use vtkGhostCellsGenerator instead") VTKFILTERSPARALLELGEOMETRY_EXPORT vtkPDataSetGhostGenerator
+  : public vtkDataSetGhostGenerator
 {
 public:
-   vtkTypeMacro(vtkPDataSetGhostGenerator,vtkDataSetGhostGenerator);
-   void PrintSelf(ostream& os, vtkIndent indent) override;
+  vtkTypeMacro(vtkPDataSetGhostGenerator, vtkDataSetGhostGenerator);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-   //@{
-   /**
-    * Get/Set macro for the multi-process controller. If a controller is not
-    * supplied, then, the global controller is assumed.
-    */
-   vtkSetMacro(Controller, vtkMultiProcessController*);
-   vtkGetMacro(Controller, vtkMultiProcessController*);
-   //@}
+  ///@{
+  /**
+   * Get/Set macro for the multi-process controller. If a controller is not
+   * supplied, then, the global controller is assumed.
+   */
+  void SetController(vtkMultiProcessController*);
+  vtkGetObjectMacro(Controller, vtkMultiProcessController);
+  ///@}
 
-   /**
-    * Initializes
-    */
-   void Initialize();
+  /**
+   * Initializes
+   */
+  void Initialize();
 
-   /**
-    * Barrier synchronization
-    */
-   void Barrier();
+  /**
+   * Barrier synchronization
+   */
+  void Barrier();
 
 protected:
   vtkPDataSetGhostGenerator();
@@ -67,11 +69,11 @@ protected:
    * Creates ghost layers. Implemented by concrete implementations.
    */
   virtual void GenerateGhostLayers(
-      vtkMultiBlockDataSet *in, vtkMultiBlockDataSet *out) override = 0;
+    vtkMultiBlockDataSet* in, vtkMultiBlockDataSet* out) override = 0;
 
   int Rank;
   bool Initialized;
-  vtkMultiProcessController *Controller;
+  vtkMultiProcessController* Controller;
 
 private:
   vtkPDataSetGhostGenerator(const vtkPDataSetGhostGenerator&) = delete;
@@ -79,3 +81,5 @@ private:
 };
 
 #endif /* vtkPDataSetGhostGenerator_h */
+
+// VTK-HeaderTest-Exclude: vtkPDataSetGhostGenerator.h
