@@ -7,7 +7,7 @@
 #  define VTKRENDERINGQT_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGQT_EXPORT
-#    ifdef vtkRenderingQt_EXPORTS
+#    ifdef RenderingQt_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGQT_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,20 @@
 
 #ifndef VTKRENDERINGQT_DEPRECATED
 #  define VTKRENDERINGQT_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGQT_DEPRECATED_EXPORT VTKRENDERINGQT_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGQT_DEPRECATED_NO_EXPORT VTKRENDERINGQT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGQT_NO_DEPRECATED
+#ifndef VTKRENDERINGQT_DEPRECATED_EXPORT
+#  define VTKRENDERINGQT_DEPRECATED_EXPORT VTKRENDERINGQT_EXPORT VTKRENDERINGQT_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkRenderingCoreModule.h"
-#include "vtkRenderingLabelModule.h"
-
+#ifndef VTKRENDERINGQT_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGQT_DEPRECATED_NO_EXPORT VTKRENDERINGQT_NO_EXPORT VTKRENDERINGQT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGQT_NO_DEPRECATED
+#    define VTKRENDERINGQT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKRENDERINGQT_EXPORT_H */
